@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Spam Buttons Plugin
-  * Copyright (c) 2005-2008 Paul Lesniewski <paul@squirrelmail.org>,
+  * Copyright (c) 2005-2009 Paul Lesniewski <paul@squirrelmail.org>,
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -119,8 +119,10 @@ function sb_no_op()
    $ignore = _("Blacklist");
    $ignore = _("Blacklist Sender");
    $ignore = _("Blacklist Sender");
+   $ignore = ngettext("Sender has been blacklisted", "Senders have been blacklisted", 1);
    $ignore = _("Sender has been blacklisted");
    $ignore = _("Senders have been blacklisted");
+   $ignore = ngettext("Sender has been whitelisted", "Senders have been whitelisted", 1);
    $ignore = _("Sender has been whitelisted");
    $ignore = _("Senders have been whitelisted");
 }
@@ -142,7 +144,7 @@ function spam_buttons_info()
                        'sm_site_username' => 'pdontthink',
                     ),
                  ),
-                 'version' => '2.2',
+                 'version' => '2.3',
                  'required_sm_version' => '1.4.0',
                  'requires_configuration' => 1,
                  'summary' => 'Puts Spam/Not Spam buttons on mailbox list and message view pages.',
@@ -159,7 +161,7 @@ function spam_buttons_info()
                        'requires_source_patch' => 1,
                        'required_plugins' => array(
                           'compatibility' => array(
-                             'version' => '2.0.7',
+                             'version' => '2.0.12',
                              'activate' => FALSE,
                           )
                        )
